@@ -75,7 +75,7 @@ class MetaDataStorageHandlerPdo extends MetaDataStorageSource
      * @return array $metadata Associative array with the metadata, or NULL if we are unable to load metadata from the
      *     given file.
      *
-     * @throws Exception If a database error occurs.
+     * @throws \Exception If a database error occurs.
      * @throws \SimpleSAML\Error\Exception If the metadata can be retrieved from the database, but cannot be decoded.
      */
     private function load($set)
@@ -130,12 +130,9 @@ class MetaDataStorageHandlerPdo extends MetaDataStorageSource
             $metadataSet = [];
         }
 
+        /** @var array $metadataSet */
         foreach ($metadataSet as $entityId => &$entry) {
-            if (preg_match('/__DYNAMIC(:[0-9]+)?__/', $entityId)) {
-                $entry['entityid'] = $this->generateDynamicHostedEntityID($set);
-            } else {
-                $entry['entityid'] = $entityId;
-            }
+            $entry = $this->updateEntityID($set, $entityId, $entry);
         }
 
         $this->cachedMetadata[$set] = $metadataSet;
@@ -156,63 +153,67 @@ class MetaDataStorageHandlerPdo extends MetaDataStorageSource
         assert(is_string($entityId));
         assert(is_string($set));
 
-        $tableName = $this->getTableName($set);
-
+        // validate the metadata set is valid
         if (!in_array($set, $this->supportedSets, true)) {
             return null;
         }
 
-        $stmt = $this->db->read(
-            "SELECT entity_id, entity_data FROM $tableName WHERE entity_id=:entityId",
-            ['entityId' => $entityId]
-        );
-        if ($stmt->execute()) {
-            $rowCount = 0;
-            $data = null;
+        // support caching
+        if (isset($this->cachedMetadata[$entityId][$set])) {
+            return $this->cachedMetadata[$entityId][$set];
+        }
 
-            while ($d = $stmt->fetch()) {
-                if (++$rowCount > 1) {
-                    \SimpleSAML\Logger::warning("Duplicate match for $entityId in set $set");
-                    break;
-                }
-                $data = json_decode($d['entity_data'], true);
-                if ($data === null) {
-                    throw new \SimpleSAML\Error\Exception("Cannot decode metadata for entity '${d['entity_id']}'");
-                }
-                if (!array_key_exists('entityid', $data)) {
-                    $data['entityid'] = $d['entity_id'];
-                }
-            }
-            return $data;
-        } else {
+        $tableName = $this->getTableName($set);
+
+        // according to the docs, it looks like *-idp-hosted metadata are the types
+        // that allow the __DYNAMIC:*__ entity id.  with the current table design
+        // we need to lookup the specific metadata entry but also we need to lookup
+        // any dynamic entries to see if the dynamic hosted entity id matches
+        if (substr($set, -10) == 'idp-hosted') {
+            $stmt = $this->db->read(
+                "SELECT entity_id, entity_data FROM {$tableName} WHERE (entity_id LIKE :dynamicId OR entity_id = :entityId)",
+                ['dynamicId' => '__DYNAMIC%', 'entityId' => $entityId]
+            );
+        }
+        // other metadata types should be able to match on entity id
+        else {
+            $stmt = $this->db->read(
+                "SELECT entity_id, entity_data FROM {$tableName} WHERE entity_id = :entityId",
+                ['entityId' => $entityId]
+            );
+        }
+
+        // throw pdo exception upon execution failure
+        if (!$stmt->execute()) {
             throw new \Exception('PDO metadata handler: Database error: '.var_export($this->db->getLastError(), true));
         }
     }
 
+
     private function generateDynamicHostedEntityID($set)
     {
         assert(is_string($set));
 
-        // get the configuration
-        $baseurl = \SimpleSAML\Utils\HTTP::getBaseURL();
+        // load the metadata into an array
+        $metadataSet = [];
+        while ($d = $stmt->fetch()) {
+            $data = json_decode($d['entity_data'], true);
+            if (json_last_error() != JSON_ERROR_NONE) {
+                throw new \SimpleSAML\Error\Exception("Cannot decode metadata for entity '${d['entity_id']}'");
+            }
 
-        if ($set === 'saml20-idp-hosted') {
-            return $baseurl.'saml2/idp/metadata.php';
-        } elseif ($set === 'saml20-sp-hosted') {
-            return $baseurl.'saml2/sp/metadata.php';
-        } elseif ($set === 'shib13-idp-hosted') {
-            return $baseurl.'shib13/idp/metadata.php';
-        } elseif ($set === 'shib13-sp-hosted') {
-            return $baseurl.'shib13/sp/metadata.php';
-        } elseif ($set === 'wsfed-sp-hosted') {
-            return 'urn:federation:'.\SimpleSAML\Utils\HTTP::getSelfHost();
-        } elseif ($set === 'adfs-idp-hosted') {
-            return 'urn:federation:'.\SimpleSAML\Utils\HTTP::getSelfHost().':idp';
-        } else {
-            throw new \Exception('Can not generate dynamic EntityID for metadata of this type: ['.$set.']');
+            // update the entity id to either the key (if not dynamic or generate the dynamic hosted url)
+            $metadataSet[$d['entity_id']] = $this->updateEntityID($set, $entityId, $data);
         }
-    }
 
+        $indexLookup = $this->lookupIndexFromEntityId($entityId, $metadataSet);
+        if (isset($indexLookup) && array_key_exists($indexLookup, $metadataSet)) {
+            $this->cachedMetadata[$indexLookup][$set] = $metadataSet[$indexLookup];
+            return $this->cachedMetadata[$indexLookup][$set];
+        }
+
+        return null;
+    }
 
     /**
      * Add metadata to the configured database
