@@ -4,15 +4,14 @@ namespace SimpleSAML\Test\Locale;
 
 use PHPUnit\Framework\TestCase;
 use SimpleSAML\Locale\Localization;
-use \SimpleSAML_Configuration as Configuration;
-
+use \SimpleSAML\Configuration;
 
 class LocalizationTest extends TestCase
 {
     protected function setUp()
     {
         // Localization/Language code attempts to load a cookie, and looks in the config for a name of the cookie
-        Configuration::loadFromArray(array(), '[ARRAY]', 'simplesaml');
+        Configuration::loadFromArray([], '[ARRAY]', 'simplesaml');
     }
 
 
@@ -22,8 +21,8 @@ class LocalizationTest extends TestCase
     public function testLocalization()
     {
         // The constructor should activate the default domain
-        $c = \SimpleSAML_Configuration::loadFromArray(
-            array('language.i18n.backend' => 'SimpleSAMLphp')
+        $c = Configuration::loadFromArray(
+            ['usenewui' => false]
         );
         $l = new Localization($c);
         $this->assertTrue($l->isI18NBackendDefault());
@@ -35,8 +34,8 @@ class LocalizationTest extends TestCase
      */
     public function testAddDomain()
     {
-        $c = \SimpleSAML_Configuration::loadFromArray(
-            array('language.i18n.backend' => 'gettext/gettext')
+        $c = Configuration::loadFromArray(
+            ['usenewui' => true]
         );
         $l = new Localization($c);
         $newDomain = 'test';
@@ -46,5 +45,4 @@ class LocalizationTest extends TestCase
         $this->assertArrayHasKey($newDomain, $registeredDomains);
         $this->assertEquals($registeredDomains[$newDomain], $newDomainLocaleDir);
     }
-
 }
